@@ -4,7 +4,7 @@ use bytes::Bytes;
 use hyper::body::HttpBody;
 use tower::{Service, ServiceExt};
 
-use crate::{body::BodyStream, Endpoint, Request, Response, Result};
+use crate::{body::BodyStream, error::InternalServerError, Endpoint, Request, Response, Result};
 
 /// Extension trait for tower service compat.
 #[cfg_attr(docsrs, doc(cfg(feature = "tower-compat")))]
@@ -56,15 +56,18 @@ where
         + 'static,
     Fut: Future<Output = Result<hyper::Response<ResBody>, Err>> + Send + 'static,
 {
-    type Output = Result<Response>;
+    type Output = Response;
 
-    async fn call(&self, req: Request) -> Self::Output {
+    async fn call(&self, req: Request) -> Result<Self::Output> {
         let mut svc = self.0.clone();
 
-        svc.ready().await?;
+        svc.ready().await.map_err(InternalServerError)?;
 
         let hyper_req: http::Request<hyper::Body> = req.into();
-        let hyper_resp = svc.call(hyper_req.map(Into::into)).await?;
+        let hyper_resp = svc
+            .call(hyper_req.map(Into::into))
+            .await
+            .map_err(InternalServerError)?;
 
         Ok(hyper_resp
             .map(|body| hyper::Body::wrap_stream(BodyStream::new(body)))
